==> office-ui-fabric-react-0.22.1.tgz: package/lib-amd/demo/pages/DocumentCardPage/examples/DocumentCard.Basic.Example.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../../index'], function (require, exports, React, index_1) {
    "use strict";
    var DocumentCardBasicExample = (function (_super) {
        __extends(DocumentCardBasicExample, _super);
        function DocumentCardBasicExample() {
            _super.apply(this, arguments);
        }
        DocumentCardBasicExample.prototype.render = function () {
            var previewProps = {
                previewImageSrc: 'dist/document-preview.png',
                imageFit: index_1.ImageFit.none,
                width: 318,
                height: 196,
                iconSrc: 'dist/icon-ppt.png',
                accentColor: '#ce4b1f'
            };
            return (React.createElement(index_1.DocumentCard, {onClickHref: 'http://bing.com'}, React.createElement(index_1.DocumentCardPreview, React.__spread({}, previewProps)), React.createElement(index_1.DocumentCardTitle, {title: 'Revenue stream proposal fiscal year 2016 version02.pptx'}), React.createElement(index_1.DocumentCardActivity, {activity: 'Created Feb 23, 2016', people: [
                { name: 'Kat Larrson', profileImageSrc: 'dist/avatar-kat.png' }
            ]})));
        };
        return DocumentCardBasicExample;
    }(React.Component));
    exports.DocumentCardBasicExample = DocumentCardBasicExample;
});

==> office-ui-fabric-react-0.34.0.tgz: package/lib-amd/demo/pages/DocumentCardPage/examples/DocumentCard.Basic.Example.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../../../index'], function (require, exports, React, index_1) {
    "use strict";
    var DocumentCardBasicExample = (function (_super) {
        __extends(DocumentCardBasicExample, _super);
        function DocumentCardBasicExample() {
            _super.apply(this, arguments);
        }
        DocumentCardBasicExample.prototype.render = function () {
            var previewProps = {
                previewImages: [
                    {
                        previewImageSrc: 'dist/document-preview.png',
                        iconSrc: 'dist/icon-ppt.png',
                        imageFit: index_1.ImageFit.cover,
                        width: 318,
                        height: 196,
                        accentColor: '#ce4b1f'
                    }
                ],
            };
            return (React.createElement(index_1.DocumentCard, {onClickHref: 'http://bing.com'}, React.createElement(index_1.DocumentCardPreview, React.__spread({}, previewProps)), React.createElement(index_1.DocumentCardTitle, {title: 'Revenue stream proposal fiscal year 2016 version02.pptx'}), React.createElement(index_1.DocumentCardActivity, {activity: 'Created Feb 23, 2016', people: [
                { name: 'Kat Larrson', profileImageSrc: 'dist/avatar-kat.png' }
            ]})));
        };
        return DocumentCardBasicExample;
    }(React.Component));
    exports.DocumentCardBasicExample = DocumentCardBasicExample;
});
